@@ -2,7 +2,7 @@ import logging
 import pandas as pd
 import numpy as np
 
-from dataikuscoring.mlflow.common import DisableMLflowTypeEnforcement
+from dataikuscoring.mlflow.common import DisableMLflowTypeEnforcement, convert_date_features
 from dataikuscoring.utils.scoring_data import ScoringData
 from dataikuscoring.utils.prediction_result import PredictionResult
 
@@ -16,12 +16,17 @@ def mlflow_regression_predict_to_scoring_data(mlflow_model, imported_model_meta,
 
     Requires a prediction type on the MLflow model
     """
+    input_df = input_df.copy()
+    convert_date_features(imported_model_meta, input_df)
 
     logging.info("Predicting it")
 
     with DisableMLflowTypeEnforcement():
         output = mlflow_model.predict(input_df)
 
+    if isinstance(output, list):
+        output = np.array(output)
+
     if isinstance(output, pd.DataFrame):
         logging.info("MLflow model returned a dataframe with columns: %s" % (output.columns))
         if "predictions" in output.columns and "target" in output.columns:
@@ -47,13 +52,16 @@ def mlflow_regression_predict_to_scoring_data(mlflow_model, imported_model_meta,
     if mlflow_raw_preds.shape[0] == 0:
         raise Exception("Cannot work with no data at input")
 
+    if not pd.api.types.is_numeric_dtype(mlflow_raw_preds):
+        mlflow_raw_preds = mlflow_raw_preds.astype(float)
+
     preds = mlflow_raw_preds
     pred_df = pd.DataFrame({"prediction": preds})
 
     if np.isnan(pred_df.to_numpy()).any():
         raise Exception("MLflow model predicted NaN probabilities")
 
-    logger.info("Final pred_df: %s " % pred_df)
+    logger.debug("Final pred_df: %s " % pred_df)
 
     # Fix indexing to match the input_df
     pred_df.index = input_df.index
